@@ -1,13 +1,13 @@
 ;;; no-littering.el --- Help keeping ~/.config/emacs clean  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2016-2026 Jonas Bernoulli
+;; Copyright (C) 2016-2025 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.no-littering@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.8.5
-;; Package-Revision: v1.8.5-0-g3b1d39d6b37f
+;; Package-Version: 20251011.1825
+;; Package-Revision: 09d07714904f
 ;; Package-Requires: (
 ;;     (emacs  "26.1")
 ;;     (compat "30.1"))
@@ -135,10 +135,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq ede-project-placeholder-cache-file (var "ede-projects.el"))
     (setq erc-dcc-get-default-directory    (var "erc/dcc/"))
     (setq erc-log-channels-directory       (var "erc/log-channels/"))
-    (setq erc-startup-file-list            (list (etc "erc/startup.el")
-                                                 (etc "erc/startup")
-                                                 ".ercrc.el"
-                                                 ".ercrc"))
+    (setq erc-startup-file-list            (list (etc "erc/startup.el") (etc "erc/startup") ".ercrc.el" ".ercrc"))
     (setq eshell-aliases-file              (etc "eshell/aliases"))
     ;; This controls where `eshell-history-file-name' is places.
     ;; Other files belong in "etc/" so theme their variables directly.
@@ -204,8 +201,6 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'newsticker  `(make-directory ,(var "newsticker/") t))
     (eval-after-load 'org         `(make-directory ,(var "org/") t))
     (eval-after-load 'shadowfile  `(make-directory ,(var "shadow/") t))
-    (eval-after-load 'treesit     `(when (treesit-available-p)
-                                     (push ,(var "treesit/") treesit-extra-load-path)))
 
 ;;; Third-party packages
 
@@ -274,8 +269,6 @@ This variable has to be set before `no-littering' is loaded.")
     (setq gnus-notes-file                  (var "gnus-notes/articles.el"))
     (setq gnus-notes-top-dir               (var "gnus-notes/"))
     (setq gptel-crowdsourced-prompts-file  (var "gptel-crowdsourced-prompts.csv"))
-    (setq gptel-gh-token-file              (var "gptel/gh-token"))
-    (setq gptel-gh-github-token-file       (var "gptel/gh-github-token"))
     (setq grammalecte-settings-file        (etc "grammalecte-settings.el"))
     (setq hackernews-visited-links-file    (var "hackernews/visited-links.el"))
     (setq harpoon-cache-file               (var "harpoon/"))
@@ -307,12 +300,10 @@ This variable has to be set before `no-littering' is loaded.")
     (setq lsp-session-file                 (var "lsp/session.el"))
     (setq magithub-cache-file              (var "magithub/cache.el"))
     (setq magithub-dir                     (var "magithub/"))
-    (setq mason-dir                        (var "mason/"))
     (setq mastodon-client--token-file      (var "mastodon-client--token"))
     (setq mc/list-file                     (var "mc-list.el"))
     (setq meghanada-server-install-dir     (var "meghanada/"))
     (setq multi-compile-history-file       (var "multi-compile-history.el"))
-    (setq neocaml-repl-history-file        (var "neocaml-repl-history"))
     (setq nix-buffer-directory-name        (var "nix-buffer/"))
     (setq nomad-tramp-script-directory     (var "nomad-tramp/"))
     ;; The value of this variable MUST NOT end with ".el" but the
@@ -492,6 +483,5 @@ you must turn of these features completely."
 (provide 'no-littering)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
-;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; no-littering.el ends here
